@@ -20,6 +20,7 @@ class QNetworkAccessManager;
 class QNetworkReply;
 class QMediaPlaylist;
 class QTimer;
+class QListWidgetItem;
 
 class ChannelsForm : public QWidget
 {
@@ -65,6 +66,7 @@ private slots:
     void updateStatus(const QString &s);
 
     void updateChannelInfo(int position);
+    void updateChannelInfo(QListWidgetItem *item);
 
     void abortFetching();
 
